@@ -39,6 +39,7 @@
 #' bootstrap, k-fold cross-validation and subsampling are implemented.
 #' @param levels the confidence levels required. If NULL, the 
 #' raw results are returned. 
+#' @param verbose if \code{TRUE}, information will be printed in the console
 #' @param ... further arguments passed to \code{\link{applyFolds}} if
 #' the default for \code{resampling_fun_outer} is used
 #'
@@ -88,7 +89,7 @@
 #'
 #'}
 #'               
-#' \dontrun{             
+#' \donttest{             
 #' # a short toy example with to few folds  
 #' # and up to 200 boosting iterations 
 #' bootCIs <- bootstrapCI(m1[200], B_inner = 2, B_outer = 5) 
@@ -110,14 +111,14 @@
 #' ), mc.cores = 10) # use ten cores
 #' }
 #' 
-#' \dontrun{
+#' \donttest{
 #' bootCIs <- bootstrapCI(m1, resampling_fun_inner = my_inner_fun)
 #' }
 #' 
 #' ## We can also use the ... argument to parallelize the applyFolds
 #' ## function in the outer resampling 
 #' 
-#' \dontrun{
+#' \donttest{
 #' bootCIs <- bootstrapCI(m1, mc.cores = 30)
 #' }
 #' 
@@ -162,7 +163,7 @@
 #'                timeformula = NULL, data = fuelSubset) 
 #' 
 #' 
-#' \dontrun{
+#' \donttest{
 #' # takes some time, because of defaults: B_outer = 100, B_inner = 25
 #' bootCIs <- bootstrapCI(mod2)
 #' }
@@ -170,7 +171,7 @@
 #' ## run with a larger number of outer bootstrap samples
 #' ## and only 10-fold for validation of each outer fold
 #' ## WARNING: This may take very long!
-#' \dontrun{
+#' \donttest{
 #' bootCIs <- bootstrapCI(mod2, B_outer = 1000, B_inner = 10)
 #' }
 #' 
@@ -182,6 +183,7 @@ bootstrapCI <- function(object, which = NULL,
                         B_inner = 25,
                         type_inner = c("bootstrap", "kfold", "subsampling"),
                         levels = c(0.05, 0.95),
+                        verbose = TRUE,
                         ...)
 {
   
@@ -234,7 +236,7 @@ bootstrapCI <- function(object, which = NULL,
     stop("Please specify a different outer resampling function.")
   
   ########## get coefficients ##########
-  cat("Start computing bootstrap confidence intervals... \n")
+  if(verbose) cat("Start computing bootstrap confidence intervals... \n")
   
   results <- resampling_fun_outer(object, 
                                   fun = function(mod)
@@ -245,7 +247,7 @@ bootstrapCI <- function(object, which = NULL,
                                   }
                                   )
   
-  cat("\n")
+  if(verbose) cat("\n")
   
   coefs <- lapply(results, "[[", "coefs")
   mstops <- sapply(results, "[[", "ms")
@@ -516,6 +518,9 @@ plot.bootstrapCI <- function(x, which = NULL, pers = TRUE,
   
   if(is.null(which)) which <- 1:length(x$raw_results)
   
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar))
+  
   if(length(which)>1) par(ask=ask)
   
   # find common range for all effects 
